***************************
* File: enseignant.do 
* Questionnaire type: Health Facility
* Country: Madagascar
*****************************

version 10.1
cd "Source\Madagascar 2006 P E\"
capture clear
capture log close
clear
set mem 700m
set more off

use "4- Data\4.1. Raw Data\Second Round\enseignant_ecole\enseignant.dta"

**************************************************
***   Ensure all variables are present and labeled.
**************************************************
log using "enseignant", replace
codebook, compact
log close

label var  grandi "lieu o grandi"
**************************************************
***   Ensure response value labels are correct.
**************************************************
label save using "enseignant", replace

**************************************************
***   Unique identifiers: ID
**************************************************
 egen ID=concat(  codecole cod_ensgt)
destring ID, replace
order  codecole cod_ensgt  ID
label var ID "identifiant unique"

**************************************************
***   Recode missing values
***************************************************
*    DECODE MISSING VALUES
# d ;
qui mvdecode   assoc , mv(
5=.d);
# d cr;

**************************************************
***  Identify skip patterns
**************************************************
* Recode missing values to Stata missing values, for tests and data inspection.
quietly mvdecode _all,mv (-666 = .d \ -777 = .n \ -888 = .l \ -999 = .r) 

foreach v of varlist   an_ensgt-per_autre non_paye-nature  aut_actv1- assoc{
	gen error01`v' = (present == 2 & `v'< . )
}

foreach v of varlist categ cadre retard {
	gen error02`v' = (position== 2 & `v'< . )
}
foreach v of varlist categ cadre retard {
	gen error03`v' = (position== 3 & `v'< . )
}
 foreach v of varlist categ cadre retard {
	gen error04`v' = (position== 4 & `v'< . )
}
foreach v of varlist categ cadre retard {
	gen error05`v' = (position== 5 & `v'< . )
} 
gen error06mis_dispt = ( maison == 2 &    mis_disp< . )
         
gen error07nb_avce = ( mod_paie == 1 &    nb_avce< . )
gen error08nb_avce = ( mod_paie == 2 &    nb_avce< . )
gen error09nb_avce = ( mod_paie == 4 &    nb_avce< . )
gen error10nb_avce = ( mod_paie == 5 &    nb_avce< . )

foreach v of varlist   de_qui montant per_ind nature {
	gen error11`v' = (indemn  == 2 & `v'< . )
}


**************************************************
***  Identify illegal responses
**************************************************
log using "enseignant label inspect", replace
inspect
log close

**************************************************
***   Identify outliers
**************************************************
log using "enseignant grubbs", replace
preserve
global lab (		assoc	mod_paie	qui	maison	present	retard	non_paye	indemn	position	cadre	dipl_ac	ecol_prof	dipl_prof	dern_form	situat	origin	grandi	mis_disp	transp	per_etat	per_cisco	per_subv	per_parent	per_com	per_autre	per_sec	per_plui	per_ind	de_qui	nature	aut_actv1	aut_actv2)
global name (   nom_ensgt mod_nrt)
drop  $lab $name
mvdecode _all, mv(0 = .z)
grubbs _all, level(99.99)
sum grubbs*
drop grubbs* 
mvencode _all, mv(.z = 0)
log close
restore


**************************************************
***   Reviewing errors and computing responses
**************************************************
replace present=1 if ID==	20505221	|ID==	20505222	|ID==	20505223	|ID==	10923223	|ID==	10923224	|ID==	10931231	|ID==	10931234	|ID==	20401212	|ID==	51901225	|ID==	30813235	|ID==	40611233	|ID==	71631235

replace present=1 if ID==	20509233	|ID==	11131233	|ID==	301992811	|ID==	103072314	|ID==	103072315	|ID==	103072316	|ID==	22029238	|ID==	30406211	|ID==	30406212	|ID==	30406233	|ID==	30455222	|ID==	30455234	|ID==	30455235	|ID==	30406231

replace present=1 if ID== 40811232	

replace dipl_ac=. if ID==	20509233
replace	origin=. if ID==20505234
replace	nature=. if ID==20505234

foreach v of varlist   sal_etat	per_etat	sal_cisco	per_cisco	sal_subv	per_subv	sal_parent	per_parent	sal_com	per_com	sal_autre	mois_non_p	abs_long	nb_avce	indemn	montant	nature	aut_actv1	assoc{
	replace `v' =. if ID==10923221	|ID==11405221	|ID==11405223	|ID==	11405232	|ID==	11405234	|ID==	11405235	|ID==	20601233	|ID==	20607222	|ID==	20607232	|ID==	20705221	|ID==	20705223	|ID==	21329236	|ID==	21343232	|ID==	51119211	|ID==	30199247	|ID==	40912212	|ID==	40912232	|ID==	71631221
}

replace present=1 if ID==	11419214	|ID==	11423211	|ID==	51402232	|ID==	51455221

foreach v of varlist   mod_paie	nb_avce	jr_retard{
	replace `v' =. if ID==11216232
}

foreach v of varlist  	indemn	montant	nature	aut_actv1	assoc{
	replace `v' =. if ID==301992820 |ID==	301992823	|ID==	30802211
}

foreach v of varlist nature	aut_actv1	assoc{
	replace `v' =. if ID==20509235 |ID==	10609211
}

foreach v of varlist position	cadre	retard{
	replace `v' =. if ID==22029223 |ID==	22029232|ID==	30455238
}

replace nb_avce=. if ID==	11103221	|ID==	11205231	|ID==	11216211	|ID==	11255211	|ID==	21329211	|ID==	21341231	|ID==	30802232	|ID==	30802233	|ID==	30802234	|ID==	31431231	|ID==	71906231
replace nb_avce=. if ID==	11205221	|ID==	11205232	|ID==	11216231	|ID==	11216233	|ID==	11255221	|ID==	11255231	|ID==	21343231	|ID==	30802231	|ID==	31431232	|ID==	10313212
replace nb_avce=. if ID==	20509236	|ID==	10923223	|ID==	10937221	|ID==	10937222	|ID==	10937232	|ID==	10937233	|ID==	10937234	|ID==	10937235	|ID==	11103211	|ID==	11103212	|ID==	11103222	|ID==	11103223	|ID==	11205211	|ID==	11205212	|ID==	11205222	|ID==	11205223	|ID==	11205233	|ID==	11205234	|ID==	11205235	|ID==	11216212	|ID==	11216213	|ID==	11216222	|ID==	11216224	|ID==	11216225	|ID==	11216234	|ID==	11216235	|ID==	11216236	|ID==	11216237	|ID==	11216238	|ID==	11255212	|ID==	11255213	|ID==	11255222	|ID==	11255223	|ID==	11255224	|ID==	11255232	|ID==	21329212	|ID==	21329233	|ID==	21329234	|ID==	21341212	|ID==	21341213	|ID==	21341221	|ID==	21341222	|ID==	21341223	|ID==	21341232	|ID==	21341233	|ID==	21341234	|ID==	21343235	|ID==	51209211	|ID==	30803211	|ID==	31431233	|ID==	10313213	|ID==	71627211	|ID==	71627232	|ID==	71627233	|ID==	71904211	|ID==	22033232
replace nb_avce=. if ID==	10923222	|ID==	71629221

foreach v of varlist de_qui	montant	nature{
	replace `v' =. if ID==11131221
}

replace  montant =. if   error11montant==1
replace nature =. if   error11nature==1
drop error* 

**************************************************
*** FINAL  : Delivrables
**************************************************

*Codebook
cd "Source\Madagascar 2006 P E\4- Data\4.3. Clean Data\4.3.3. Data Code Book\Second Round\enseignant_ecole"
log using "enseignant codebook", replace
codebook, compact
log close

*Save cleaned data
cd "Source\Madagascar 2006 P E\4- Data\4.3. Clean Data\4.3.1. Final Data\Second Round\enseignant_ecole"
save "enseignant_cleaned_data.dta", replace
